==> chemistry-opencmis-commons-impl-0.6.0-sources.jar: org/apache/chemistry/opencmis/commons/impl/dataobjects/PropertyDateTimeDefinitionImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.commons.impl.dataobjects;

import java.util.GregorianCalendar;

import org.apache.chemistry.opencmis.commons.definitions.PropertyDateTimeDefinition;
import org.apache.chemistry.opencmis.commons.enums.DateTimeResolution;

/**
 * DateTime property definition data implementation.
 * 
 * @author <a href="mailto:fmueller@opentext.com">Florian M&uuml;ller</a>
 * 
 */
public class PropertyDateTimeDefinitionImpl extends AbstractPropertyDefinition<GregorianCalendar> implements
        PropertyDateTimeDefinition {

    private static final long serialVersionUID = 1L;

    private DateTimeResolution fDateTimeResolution;

    /*
     * (non-Javadoc)
     * 
     * @seeorg.apache.opencmis.client.provider.PropertyDateTimeDefinitionData#
     * getDateTimeResolution()
     */
    public DateTimeResolution getDateTimeResolution() {
        return fDateTimeResolution;
    }

    public void setDateTimeResolution(DateTimeResolution dateTimeResolution) {
        fDateTimeResolution = dateTimeResolution;
    }
}

==> chemistry-opencmis-commons-impl-0.10.0-sources.jar: org/apache/chemistry/opencmis/commons/impl/dataobjects/PropertyDateTimeDefinitionImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.commons.impl.dataobjects;

import java.util.GregorianCalendar;

import org.apache.chemistry.opencmis.commons.definitions.MutablePropertyDateTimeDefinition;
import org.apache.chemistry.opencmis.commons.enums.DateTimeResolution;

/**
 * DateTime property definition data implementation.
 */
public class PropertyDateTimeDefinitionImpl extends AbstractPropertyDefinition<GregorianCalendar> implements
        MutablePropertyDateTimeDefinition {

    private static final long serialVersionUID = 1L;

    private DateTimeResolution dateTimeResolution;

    public DateTimeResolution getDateTimeResolution() {
        return dateTimeResolution;
    }

    public void setDateTimeResolution(DateTimeResolution dateTimeResolution) {
        this.dateTimeResolution = dateTimeResolution;
    }
}
